:orphan:

.. _benefits:

**************************************************
Benefits
**************************************************

Automation
-------------

FlexMeasures provides decision-making support so that the platform operator can schedule flexibility activations.
It forecasts the state of assets and proposes the best flexibility activations (shifting or curtailment)
for future periods. This is done with modern forecasting and scheduling intelligence.

Insight
--------------
Both platform operator and asset owners can monitor the assets - past and current states as well as forecasts are displayed numerically in plots and tables.
Activations of flexibility which were ordered in the past can be reviewed.
Proposed and scheduled flexibility activations show their expected effects (on imbalance as well as on financial returns).

Autonomy
--------------
The companies connected to FlexMeasures only give up as much control as necessary. The asset owners still control the main behaviour of their assets.
The owners allow the platform operator to schedule flexibility activations within limits they can set.

Also the platform operator stays in charge:
They can choose to approve all proposed flexibility activations manually or to let FlexMeasures automatically schedule them.
As FlexMeasures is open source, they can choose to host it themselves or let a third party (like Seita BV) do that.

Profit sharing
---------------
The platform operator (as ESCo or Aggregator) and asset owners can share the profit made from flexibility activations between them.
FlexMeasures plans on providing basic accounting for this.


.. note:: Read more on flexibility opportunities and activations, as well as profit sharing on :ref:`benefits_of_flex`
